@@ -133,8 +133,8 @@ int main(int argc, char **argv) /* qmove */
 cnt:
         connect = cnt2server(server_out);
         if ( connect <= 0 ) {
-            fprintf(stderr, "qmove: cannot connect to server %s (errno=%d)\n", 
-                    pbs_server, pbs_errno);
+            fprintf(stderr, "qmove: cannot connect to server %s (errno=%d) %s\n", 
+                    pbs_server, pbs_errno, pbs_strerror(pbs_errno));
             any_failed = pbs_errno;
             continue;
         }
