@@ -216,9 +216,10 @@ cnt:
 
     if (connect <= 0) 
       {
-      fprintf(stderr, "qrls: cannot connect to server %s (errno=%d)\n", 
+      fprintf(stderr, "qrls: cannot connect to server %s (errno=%d) %s\n", 
         pbs_server, 
-        pbs_errno);
+        pbs_errno,
+        pbs_strerror(pbs_errno));
 
       any_failed = pbs_errno;
 
