@@ -205,7 +205,8 @@ struct grpcache {
  * define the size of the array.
  */
 
-/* sync w/XXX */
+/* sync w/ src/server/job_attr_def.c */
+/* sync w/ src/resmom/request.c TJobAttr constants */
 
 enum job_atr {
   JOB_ATR_jobname,	/* this set appears first as they show */
@@ -262,7 +263,7 @@ enum job_atr {
   JOB_ATR_submit_args,
   JOB_ATR_job_array_id,
   JOB_ATR_job_array_request,
-  JOB_ATR_umask,
+  JOB_ATR_umask,        /* 50 */
   JOB_ATR_start_time,  /* time when job was first started */
   JOB_ATR_start_count, /* number of times the job has been started */
   JOB_ATR_chkptdir,    /* directory where job checkpoint file is stored */
@@ -763,6 +764,7 @@ extern job  *job_recov A_((char *));
 extern int   job_save A_((job *,int));
 extern int   modify_job_attr A_((job *,svrattrl *,int,int *));
 extern char *prefix_std_file A_((job *,int));
+extern char *add_std_filename A_((job *, char *, int));
 extern int   set_jobexid A_((job *,attribute *,char *));
 extern int   site_check_user_map A_((job *,char *,char *));
 extern void  svr_dequejob A_((job *));
