@@ -39,7 +39,7 @@
 
 
 /*
- * PBS specific revision: @(#) $Id: md5.h 12 2005-02-22 20:59:54Z dev $
+ * PBS specific revision: @(#) $Id: md5.h 2225 2008-07-04 01:53:08Z glen $
  */
 
 #ifndef __MD5_INCLUDE__
@@ -55,9 +55,9 @@ typedef struct {
   unsigned char digest[16];     /* actual digest after MD5Final call */
 } MD5_CTX;
 
-void MD5Init ();
-void MD5Update ();
-void MD5Final ();
+void MD5Init (MD5_CTX *);
+void MD5Update (MD5_CTX *, unsigned char *, unsigned int);
+void MD5Final (MD5_CTX *);
 
 #define __MD5_INCLUDE__
 #endif /* __MD5_INCLUDE__ */
