@@ -78,7 +78,7 @@
 */
 
 /*
- * @(#) $Id: portability.h 12 2005-02-22 20:59:54Z dev $
+ * @(#) $Id: portability.h 1082 2006-10-24 05:14:20Z garrick $
  */
 
 #ifdef __STDC__
@@ -100,3 +100,14 @@
 #define volatile
 
 #endif
+
+/* The following macros are for HPUX */
+#if defined(HAVE_SETRESUID) && defined(HAVE_SETRESGID)
+# ifndef seteuid
+#  define seteuid(e) (setresuid(-1,e,-1))
+# endif
+# ifndef setegid
+#  define setegid(e) (setresgid(-1,e,-1))
+# endif
+#endif
+
