@@ -103,10 +103,8 @@
  * rather than depending on a predefined index.
  */
 
-#define MAX_RESOURCES 200 /* max. size of svr_resc_def */
-
 typedef struct resource {
-	tlist_link 	     rs_link;	/* link to other resources in list */
+	list_link 	     rs_link;	/* link to other resources in list */
 	struct resource_def *rs_defin;	/* pointer to definition entry */
 	attribute	     rs_value;	/* attribute struct holding value */
 } resource;
@@ -126,8 +124,8 @@ typedef struct resource_def {
 /* the resource definition array, only the fixed resources */
 extern resource_def svr_resc_def_const[];  
 
-/* svr_resc_def_const + resource in $PBSCONFDIR/server_priv/resources */
-extern resource_def svr_resc_def[];        
+/* svr_resc_def_const + resources in "extra_resc" server attr */
+extern resource_def *svr_resc_def;        
 
 /* size (num elements) in above  */
 extern int         svr_resc_size;       
