@@ -98,12 +98,13 @@ extern void  svr_disconnect A_((int));
 extern int   svr_get_privilege A_((char *, char *));
 extern int   srv_shutdown A_((int));
 extern void  write_node_state A_((void ));
-extern int   write_node_note A_((void ));
+extern int  write_node_note A_((void ));
 extern int   setup_nodes A_((void));
 extern int   node_avail A_((char *spec, int  *navail,
 			    int *nalloc, int *nreserved, int *ndown));
 extern void  node_unreserve A_((resource_t handle));
 extern int   node_reserve A_((char *speclist, resource_t tag));
+extern int   init_resc_defs A_((void));
 
 #ifdef JOB_H
 extern int   set_nodes A_((job *,char *,char **,char *,char *));
@@ -158,13 +159,13 @@ struct stat_cntl {		/* used in req_stat_job */
 
 extern int stat_to_mom A_((job *, struct stat_cntl *));
 
+#endif	/* STAT_CNTL */
+
 /*
  * the following defines are due to the fact that O_SYNC was not
- * POSIX standard (TDISABLEFILESYNC managed w/configure --disable-filesync) 
+ * POSIX standard (TDISABLEFILESYNC managed w/configure --enable-filesync) 
  */
 
-#endif	/* STAT_CNTL */
-
 #if TDISABLEFILESYNC
 #define O_Sync 0
 #else
