@@ -98,10 +98,12 @@
 #include "dis.h"
 #include "batch_request.h"
 
-int decode_DIS_replySvr(sock, reply)
-	int		    sock;
-	struct batch_reply *reply;
-{
+int decode_DIS_replySvr(
+
+  int                 sock,   /* I */
+  struct batch_reply *reply)  /* I (modified) */
+
+  {
 	int		      ct;
 	int		      i;
 	struct brp_select    *psel;
