@@ -88,12 +88,14 @@
 #include <stdlib.h>
 #include "libpbs.h"
 
+/* returns pbs_errno */
+
 int pbs_alterjob(
 
-  int           c,
-  char         *jobid,
-  struct attrl *attrib,
-  char         *extend)
+  int           c,       /* I */
+  char         *jobid,   /* I */
+  struct attrl *attrib,  /* I */
+  char         *extend)  /* I */
 
   {
   struct attropl *ap = (struct attropl *)NULL;
@@ -101,7 +103,7 @@ int pbs_alterjob(
 
   int i;
 	
-  if ((jobid == NULL) || (*jobid == '\0'))
+  if ((c < 0) || (jobid == NULL) || (*jobid == '\0'))
     {
     pbs_errno = PBSE_IVALREQ;
 
