@@ -136,7 +136,7 @@
 **		loadave		current load average
 */
 
-static char ident[] = "@(#) solaris5/$RCSfile$ $Revision: 991 $";
+static char ident[] = "@(#) solaris5/$RCSfile$ $Revision: 1894 $";
 
 #ifndef TRUE
 #define FALSE	0
@@ -206,12 +206,13 @@ struct	config	dependent_config[] = {
 };
 	
 /*
-**	Don't need any periodic procsessing.
-*/
+ * This routine is called on each cycle of the main loop.
+ */
+
 void
-end_proc()
+dep_main_loop_cycle()
 {
-	return;
+  /* Don't need any periodic procsessing. */
 }
 
 void
@@ -225,8 +226,6 @@ dep_initialize()
 		log_err(errno, id, "opendir");
 		return;
 	}
-
-	return;
 }
 
 void
